@@ -42,7 +42,7 @@ SQL;
         return $result;
     }
 
-    public function truncate()
+    public function truncate(): void
     {
         $sql = <<<SQL
 TRUNCATE TABLE `cfg_resource`;
