@@ -24,6 +24,7 @@ declare(strict_types=1);
 namespace Core\HostTemplate\Infrastructure\Repository;
 
 use Centreon\Domain\Log\LoggerTrait;
+use Centreon\Domain\Repository\RepositoryException;
 use Centreon\Domain\RequestParameters\Interfaces\RequestParametersInterface;
 use Centreon\Infrastructure\DatabaseConnection;
 use Centreon\Infrastructure\RequestParameters\SqlRequestParametersTranslator;
@@ -34,6 +35,7 @@ use Core\Common\Infrastructure\Repository\AbstractRepositoryRDB;
 use Core\Common\Infrastructure\RequestParameters\Normalizer\BoolToEnumNormalizer;
 use Core\Host\Application\Converter\HostEventConverter;
 use Core\Host\Domain\Model\SnmpVersion;
+use Core\HostCategory\Infrastructure\Repository\HostCategoryRepositoryTrait;
 use Core\HostTemplate\Application\Repository\ReadHostTemplateRepositoryInterface;
 use Core\HostTemplate\Domain\Model\HostTemplate;
 use Utility\SqlConcatenator;
@@ -83,7 +85,7 @@ use Utility\SqlConcatenator;
  */
 class DbReadHostTemplateRepository extends AbstractRepositoryRDB implements ReadHostTemplateRepositoryInterface
 {
-    use LoggerTrait;
+    use LoggerTrait, HostCategoryRepositoryTrait;
 
     /**
      * @param DatabaseConnection $db
@@ -192,6 +194,139 @@ class DbReadHostTemplateRepository extends AbstractRepositoryRDB implements Read
         return $hostTemplates;
     }
 
+    /**
+     * @inheritDoc
+     */
+    public function findByRequestParametersAndAccessGroups(
+        RequestParametersInterface $requestParameters,
+        array $accessGroups
+    ): array {
+        $this->info('Getting all host templates');
+        if ($accessGroups === []) {
+            return [];
+        }
+
+        $accessGroupIds = array_map(
+            static fn($accessGroup) => $accessGroup->getId(),
+            $accessGroups
+        );
+
+        $subRequest = $this->generateHostCategoryAclSubRequest($accessGroupIds);
+        $categoryAcls = empty($subRequest)
+            ? ''
+            : <<<SQL
+                AND hc.hc_id IN ({$subRequest})
+                SQL;
+
+        $request = <<<SQL
+            SELECT SQL_CALC_FOUND_ROWS
+                h.host_id,
+                h.host_name,
+                h.host_alias,
+                h.host_snmp_version,
+                h.host_snmp_community,
+                h.host_location,
+                h.command_command_id,
+                h.command_command_id_arg1,
+                h.timeperiod_tp_id,
+                h.host_max_check_attempts,
+                h.host_check_interval,
+                h.host_retry_check_interval,
+                h.host_active_checks_enabled,
+                h.host_passive_checks_enabled,
+                h.host_notifications_enabled,
+                h.host_notification_options,
+                h.host_notification_interval,
+                h.timeperiod_tp_id2,
+                h.cg_additive_inheritance,
+                h.contact_additive_inheritance,
+                h.host_first_notification_delay,
+                h.host_recovery_notification_delay,
+                h.host_acknowledgement_timeout,
+                h.host_check_freshness,
+                h.host_freshness_threshold,
+                h.host_flap_detection_enabled,
+                h.host_low_flap_threshold,
+                h.host_high_flap_threshold,
+                h.host_event_handler_enabled,
+                h.command_command_id2,
+                h.command_command_id_arg2,
+                h.host_comment,
+                h.host_locked,
+                ehi.ehi_notes_url,
+                ehi.ehi_notes,
+                ehi.ehi_action_url,
+                ehi.ehi_icon_image,
+                ehi.ehi_icon_image_alt,
+                (
+                    SELECT hc.hc_id
+                    FROM `:db`.hostcategories hc
+                    INNER JOIN `:db`.hostcategories_relation hcr
+                           ON hc.hc_id = hcr.hostcategories_hc_id
+                    WHERE hc.level IS NOT NULL
+                      AND hcr.host_host_id = h.host_id
+                    ORDER BY hc.level, hc.hc_id
+                    LIMIT 1
+                ) AS severity_id
+            FROM `:db`.host h
+            LEFT JOIN `:db`.extended_host_information ehi
+                ON h.host_id = ehi.host_host_id
+            LEFT JOIN `:db`.hostcategories_relation hcr
+                ON hcr.host_host_id = h.host_id
+            LEFT JOIN `:db`.hostcategories hc
+                ON hc.hc_id = hcr.hostcategories_hc_id
+                AND hc.level IS NOT NULL
+            WHERE h.host_register = :host_template_type
+                {$categoryAcls}
+            SQL;
+
+        $sqlTranslator = new SqlRequestParametersTranslator($requestParameters);
+        $sqlTranslator->setConcordanceArray([
+            'id' => 'h.host_id',
+            'name' => 'h.host_name',
+            'alias' => 'h.host_alias',
+            'is_locked' => 'h.host_locked',
+        ]);
+        $sqlTranslator->addNormalizer('is_locked', new BoolToEnumNormalizer());
+
+        if ($search = $sqlTranslator->translateSearchParameterToSql()) {
+            $request .= str_replace('WHERE', 'AND', $search);
+        }
+
+        $request .= <<<'SQL'
+                GROUP BY h.host_id
+            SQL;
+
+        if ($sort = $sqlTranslator->translateSortParameterToSql()) {
+            $request .= $sort;
+        }
+
+        if ($pagination = $sqlTranslator->translatePaginationToSql()) {
+            $request .= $pagination;
+        }
+
+        $statement = $this->db->prepare($this->translateDbName($request));
+
+        $statement->bindValue(':host_template_type', HostType::Template->value, \PDO::PARAM_STR);
+        if ($this->hasRestrictedAccessToHostCategories($accessGroupIds)) {
+            foreach ($accessGroupIds as $index => $accessGroupId) {
+                $statement->bindValue(':access_group_id_' . $index, $accessGroupId, \PDO::PARAM_INT);
+            }
+        }
+        $sqlTranslator->bindSearchValues($statement);
+
+        $statement->execute();
+
+        $sqlTranslator->calculateNumberOfRows($this->db);
+        $hostTemplates = [];
+        while (is_array($result = $statement->fetch(\PDO::FETCH_ASSOC))) {
+            /** @var _HostTemplate $result */
+            $hostTemplates[] = $this->createHostTemplateFromArray($result);
+        }
+
+        return $hostTemplates;
+    }
+
     /**
      * @inheritDoc
      */
@@ -240,7 +375,7 @@ class DbReadHostTemplateRepository extends AbstractRepositoryRDB implements Read
                     ehi.ehi_action_url,
                     ehi.ehi_icon_image,
                     ehi.ehi_icon_image_alt,
-                    hcr.hostcategories_hc_id AS severity_id
+                    hc.hc_id AS severity_id
                 FROM `:db`.host h
                 LEFT JOIN `:db`.extended_host_information ehi
                     ON h.host_id = ehi.host_host_id
@@ -267,6 +402,100 @@ class DbReadHostTemplateRepository extends AbstractRepositoryRDB implements Read
         return $this->createHostTemplateFromArray($result);
     }
 
+    /**
+     * @inheritDoc
+     */
+    public function findByIdAndAccessGroups(int $hostTemplateId, array $accessGroups): ?HostTemplate
+    {
+        $this->info('Get a host template with ID #' . $hostTemplateId);
+
+        $accessGroupIds = array_map(
+            static fn($accessGroup) => $accessGroup->getId(),
+            $accessGroups
+        );
+
+        $subRequest = $this->generateHostCategoryAclSubRequest($accessGroupIds);
+        $categoryAcls = empty($subRequest)
+            ? ''
+            : <<<SQL
+                AND hc.hc_id IN ({$subRequest})
+                SQL;
+
+        $request = $this->translateDbName(
+            <<<SQL
+                SELECT
+                    h.host_id,
+                    h.host_name,
+                    h.host_alias,
+                    h.host_snmp_version,
+                    h.host_snmp_community,
+                    h.host_location,
+                    h.command_command_id,
+                    h.command_command_id_arg1,
+                    h.timeperiod_tp_id,
+                    h.host_max_check_attempts,
+                    h.host_check_interval,
+                    h.host_retry_check_interval,
+                    h.host_active_checks_enabled,
+                    h.host_passive_checks_enabled,
+                    h.host_notifications_enabled,
+                    h.host_notification_options,
+                    h.host_notification_interval,
+                    h.timeperiod_tp_id2,
+                    h.cg_additive_inheritance,
+                    h.contact_additive_inheritance,
+                    h.host_first_notification_delay,
+                    h.host_recovery_notification_delay,
+                    h.host_acknowledgement_timeout,
+                    h.host_check_freshness,
+                    h.host_freshness_threshold,
+                    h.host_flap_detection_enabled,
+                    h.host_low_flap_threshold,
+                    h.host_high_flap_threshold,
+                    h.host_event_handler_enabled,
+                    h.command_command_id2,
+                    h.command_command_id_arg2,
+                    h.host_comment,
+                    h.host_locked,
+                    ehi.ehi_notes_url,
+                    ehi.ehi_notes,
+                    ehi.ehi_action_url,
+                    ehi.ehi_icon_image,
+                    ehi.ehi_icon_image_alt,
+                    hc.hc_id AS severity_id
+                FROM `:db`.host h
+                LEFT JOIN `:db`.extended_host_information ehi
+                    ON h.host_id = ehi.host_host_id
+                LEFT JOIN `:db`.hostcategories_relation hcr
+                    ON hcr.host_host_id = h.host_id
+                LEFT JOIN `:db`.hostcategories hc
+                    ON hc.hc_id = hcr.hostcategories_hc_id
+                    AND hc.level IS NOT NULL
+                WHERE h.host_id = :host_template_id
+                    AND h.host_register = :host_template_type
+                    {$categoryAcls}
+                SQL
+        );
+
+        $statement = $this->db->prepare($this->translateDbName($request));
+        $statement->bindValue(':host_template_id', $hostTemplateId, \PDO::PARAM_INT);
+        $statement->bindValue(':host_template_type', HostType::Template->value, \PDO::PARAM_STR);
+        if ($this->hasRestrictedAccessToHostCategories($accessGroupIds)) {
+            foreach ($accessGroupIds as $index => $accessGroupId) {
+                $statement->bindValue(':access_group_id_' . $index, $accessGroupId, \PDO::PARAM_INT);
+            }
+        }
+
+        $statement->execute();
+
+        if ($result = $statement->fetch(\PDO::FETCH_ASSOC)) {
+            /** @var _HostTemplate $result */
+            return $this->createHostTemplateFromArray($result);
+        }
+
+        return null;
+    }
+
     /**
      * @inheritDoc
      */
@@ -365,14 +594,15 @@ class DbReadHostTemplateRepository extends AbstractRepositoryRDB implements Read
         $request = $this->translateDbName(
             <<<'SQL'
                 WITH RECURSIVE parents AS (
-                    SELECT * FROM `:db`.`host_template_relation`
+                    SELECT 1 as counter, host_template_relation.* FROM `:db`.`host_template_relation`
                     WHERE `host_host_id` = :hostTemplateId
                     UNION
-                    SELECT rel.* FROM `:db`.`host_template_relation` AS rel, parents AS p
+                    SELECT p.counter + 1, rel.* FROM `:db`.`host_template_relation` AS rel, parents AS p
                     WHERE rel.`host_host_id` = p.`host_tpl_id`
                 )
-                SELECT `host_host_id` AS child_id, `host_tpl_id` AS parent_id, `order`
+                SELECT counter, `host_host_id` AS child_id, `host_tpl_id` AS parent_id, `order`
                 FROM parents
+                order by counter, `order`;
                 SQL
         );
         $statement = $this->db->prepare($request);
@@ -545,6 +775,113 @@ class DbReadHostTemplateRepository extends AbstractRepositoryRDB implements Read
         return $nameById;
     }
 
+    /**
+     * @inheritDoc
+     */
+    public function findAll(): array
+    {
+        $request = $this->translateDbName(
+            <<<'SQL'
+                SELECT
+                    h.host_id,
+                    h.host_name,
+                    h.host_alias,
+                    h.host_snmp_version,
+                    h.host_snmp_community,
+                    h.host_location,
+                    h.command_command_id,
+                    h.command_command_id_arg1,
+                    h.timeperiod_tp_id,
+                    h.host_max_check_attempts,
+                    h.host_check_interval,
+                    h.host_retry_check_interval,
+                    h.host_active_checks_enabled,
+                    h.host_passive_checks_enabled,
+                    h.host_notifications_enabled,
+                    h.host_notification_options,
+                    h.host_notification_interval,
+                    h.timeperiod_tp_id2,
+                    h.cg_additive_inheritance,
+                    h.contact_additive_inheritance,
+                    h.host_first_notification_delay,
+                    h.host_recovery_notification_delay,
+                    h.host_acknowledgement_timeout,
+                    h.host_check_freshness,
+                    h.host_freshness_threshold,
+                    h.host_flap_detection_enabled,
+                    h.host_low_flap_threshold,
+                    h.host_high_flap_threshold,
+                    h.host_event_handler_enabled,
+                    h.command_command_id2,
+                    h.command_command_id_arg2,
+                    h.host_comment,
+                    h.host_locked,
+                    ehi.ehi_notes_url,
+                    ehi.ehi_notes,
+                    ehi.ehi_action_url,
+                    ehi.ehi_icon_image,
+                    ehi.ehi_icon_image_alt,
+                    hc.hc_id AS severity_id
+                FROM `:db`.host h
+                LEFT JOIN `:db`.extended_host_information ehi
+                    ON h.host_id = ehi.host_host_id
+                LEFT JOIN `:db`.hostcategories_relation hcr
+                    ON hcr.host_host_id = h.host_id
+                LEFT JOIN `:db`.hostcategories hc
+                    ON hc.hc_id = hcr.hostcategories_hc_id
+                    AND hc.level IS NOT NULL
+                WHERE h.host_register = :hostTemplateType
+                SQL
+        );
+        $statement = $this->db->prepare($request);
+        $statement->bindValue(':hostTemplateType', HostType::Template->value, \PDO::PARAM_STR);
+        $statement->execute();
+
+        $hostTemplates = [];
+
+        while ($result = $statement->fetch(\PDO::FETCH_ASSOC)) {
+            /** @var _HostTemplate $result */
+            $hostTemplates[] = $this->createHostTemplateFromArray($result);
+        }
+
+        return $hostTemplates;
+    }
+
+    /**
+     * @inheritDoc
+     */
+    public function findByHostId(int $hostId): array
+    {
+        try {
+            $request = $this->translateDbName(
+                <<<'SQL'
+                    SELECT host_tpl_id
+                    FROM host_template_relation
+                    WHERE host_host_id = :hostId
+                    ORDER BY `order` ASC
+                    SQL
+            );
+            $statement = $this->db->prepare($request);
+            $statement->bindValue(':hostId', $hostId, \PDO::PARAM_INT);
+            $statement->execute();
+
+            return $statement->fetchAll(\PDO::FETCH_COLUMN);
+        } catch (\PDOException $exception) {
+            $errorMessage = 'Error while fetching host templates by host ID';
+            $this->error($errorMessage, [
+                'host_id' => $hostId,
+                'exception' => [
+                    'message' => $exception->getMessage(),
+                    'pdo_code' => $exception->getCode(),
+                    'pdo_info' => $exception->errorInfo,
+                    'trace' => $exception->getTraceAsString(),
+                ],
+            ]);
+
+            throw new RepositoryException(message: $errorMessage, previous: $exception);
+        }
+    }
+
     /**
      * @param _HostTemplate $result
      *
