@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2022 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,29 +18,27 @@
  * For more information : contact@centreon.com
  *
  */
+
 declare(strict_types=1);
 
 namespace Core\Security\ProviderConfiguration\Infrastructure\Api\FindProviderConfigurations;
 
 use Centreon\Infrastructure\Service\Exception\NotFoundException;
-use Core\Infrastructure\Common\Api\HttpUrlTrait;
 use Core\Application\Common\UseCase\AbstractPresenter;
+use Core\Infrastructure\Common\Api\HttpUrlTrait;
 use Core\Infrastructure\Common\Presenter\PresenterFormatterInterface;
-use Core\Security\ProviderConfiguration\Infrastructure\Api\FindProviderConfigurations\ProviderPresenter\{
-    ProviderPresenterInterface
-};
 use Core\Security\ProviderConfiguration\Application\UseCase\FindProviderConfigurations\{
     FindProviderConfigurationsPresenterInterface
 };
+use Core\Security\ProviderConfiguration\Infrastructure\Api\FindProviderConfigurations\ProviderPresenter\{
+    ProviderPresenterInterface
+};
 
-class FindProviderConfigurationsPresenter extends AbstractPresenter implements
-    FindProviderConfigurationsPresenterInterface
+class FindProviderConfigurationsPresenter extends AbstractPresenter implements FindProviderConfigurationsPresenterInterface
 {
     use HttpUrlTrait;
 
-    /**
-     * @var ProviderPresenterInterface[]
-     */
+    /** @var ProviderPresenterInterface[] */
     private array $providerPresenters;
 
     /**
@@ -60,6 +58,7 @@ class FindProviderConfigurationsPresenter extends AbstractPresenter implements
 
     /**
      * {@inheritDoc}
+     *
      * @param mixed[] $data
      */
     public function present(mixed $data): void
