@@ -10,8 +10,9 @@ import {
 import { getUserContactId } from '../../../../commons';
 
 before(() => {
-  cy.startWebContainer();
-  initializeConfigACLAndGetLoginPage();
+  cy.startContainers().then(() => {
+    return initializeConfigACLAndGetLoginPage();
+  });
 });
 
 beforeEach(() => {
@@ -38,8 +39,18 @@ beforeEach(() => {
       cy.get('@user1Id').then((userid) => {
         cy.requestOnDatabase({
           database: 'centreon',
-          query: `SELECT creation_date FROM contact_password WHERE contact_id = '${userid}';`
-        }).as('user1CreationPasswordDate');
+          query: `SELECT creation_date FROM contact_password WHERE contact_id = '${userid}'`
+        })
+          .then(([rows]) => {
+            if (rows.length === 0) {
+              throw new Error(
+                `Password creation date not found for contact id ${userid}`
+              );
+            }
+
+            return rows[0].creation_date;
+          })
+          .as('user1CreationPasswordDate');
       });
     });
 
@@ -49,8 +60,18 @@ beforeEach(() => {
       cy.get('@user2Id').then((userid) => {
         cy.requestOnDatabase({
           database: 'centreon',
-          query: `SELECT creation_date FROM contact_password WHERE contact_id = '${userid}';`
-        }).as('user2CreationPasswordDate');
+          query: `SELECT creation_date FROM contact_password WHERE contact_id = '${userid}'`
+        })
+          .then(([rows]) => {
+            if (rows.length === 0) {
+              throw new Error(
+                `Password creation date not found for contact id ${userid}`
+              );
+            }
+
+            return rows[0].creation_date;
+          })
+          .as('user2CreationPasswordDate');
       });
     });
 });
@@ -109,7 +130,9 @@ When(
       .get('div[role="tablist"] button')
       .eq(0)
       .contains('Password security policy');
-    cy.get('#Minimumpasswordlength').type('{selectall}{backspace}12');
+
+    cy.get('#Minimumpasswordlength').type('{selectall}{backspace}10');
+
     cy.get('#Passwordmustcontainlowercase').should(
       'have.class',
       'MuiButton-containedPrimary'
@@ -126,7 +149,8 @@ When(
       'have.class',
       'MuiButton-containedPrimary'
     );
-    cy.get('#Save').click({ force: true });
+
+    cy.get('#Save').should('be.enabled').click();
 
     cy.logout();
 
@@ -160,7 +184,7 @@ Then(
       .find('#tab1')
       .parent()
       .contains(
-        "Your password must be 12 characters long and must contain : uppercase characters, lowercase characters, numbers, special characters among '@$!%*?&'."
+        "Your password must be 10 characters long and must contain : uppercase characters, lowercase characters, numbers, special characters among '@$!%*?&'."
       );
 
     cy.logout();
@@ -193,7 +217,7 @@ When(
       .parent()
       .click();
     cy.get('ul li[data-value="2"]').click();
-    cy.get('#Save').click({ force: true });
+    cy.get('#Save').should('be.enabled').click();
 
     cy.get('@user1Id').then((idUser) => {
       cy.get('@user1CreationPasswordDate').then((userPasswordCreationDate) => {
@@ -201,7 +225,7 @@ When(
           Number(userPasswordCreationDate) - millisecondsValueForSixMonth;
         cy.requestOnDatabase({
           database: 'centreon',
-          query: `UPDATE contact_password SET creation_date = '${newDateOfCreationDate}' WHERE contact_id = '${idUser}';`
+          query: `UPDATE contact_password SET creation_date = '${newDateOfCreationDate}' WHERE contact_id = '${idUser}'`
         });
       });
     });
@@ -253,7 +277,7 @@ When(
       .parent()
       .click();
     cy.get('ul li[data-value="2"]').click();
-    cy.get('#Save').click({ force: true });
+    cy.get('#Save').should('be.enabled').click();
 
     cy.get('@user1Id').then((idUser) => {
       cy.get('@user1CreationPasswordDate').then((userPasswordCreationDate) => {
@@ -382,7 +406,7 @@ When(
       .eq(-1)
       .find('input[type="checkbox"]')
       .check();
-    cy.get('#Save').click({ force: true });
+    cy.get('#Save').should('be.enabled').click();
 
     cy.get('@user2Id').then((idUser) => {
       cy.get('@user2CreationPasswordDate').then((userPasswordCreationDate) => {
@@ -458,7 +482,7 @@ When(
     cy.get('#Numberofattemptsbeforeuserisblocked').type(
       '{selectall}{backspace}2'
     );
-    cy.get('#Save').click({ force: true });
+    cy.get('#Save').should('be.enabled').click();
 
     cy.logout();
 
@@ -507,5 +531,5 @@ Then(
 );
 
 after(() => {
-  cy.stopWebContainer();
+  cy.stopContainers();
 });
