@@ -456,14 +456,13 @@ Cypress.Commands.add('checkValuesOfHostGroupService', (name:string, body: HostGr
       .find('option:selected')
       .should('have.length', 1)
       .and('have.text', body.servicecategories);
-
   cy.getIframeBody().find('input[name="esi_notes_url"]').should('have.value',body.noteurl);
   cy.getIframeBody().find('input[name="esi_notes"]').should('have.value',body.note);
   cy.getIframeBody().find('input[name="esi_action_url"]').should('have.value',body.actionurl);
   cy.getIframeBody().find('#esi_icon_image')
     .should('have.value', '1'); 
   cy.getIframeBody().find('input[name="esi_icon_image_alt"]').should('have.value',body.atlicon);
-  cy.getIframeBody().find('input[name="geo_coords"]').should('have.value',body.geocoords);
+  cy.getIframeBody().find('input[name="geo_coords"]').should('have.value',body.geoCoordsTruncated);
   cy.getIframeBody().find('textarea[name="service_comment"]').should('have.value',body.comment);
 });
 
@@ -562,6 +561,7 @@ interface HostGroupService {
   actionurl: string,
   atlicon: string,
   geocoords: string,
+  geoCoordsTruncated: string,
   comment: string,
 }
 
