@@ -2,6 +2,7 @@ import 'cypress-wait-until';
 import 'cypress-real-events';
 
 import './commands';
+import '../features/Resources-Access-Management/commands';
 
 before(() => {
   Cypress.config('baseUrl', 'http://127.0.0.1:4000');
@@ -16,9 +17,11 @@ Cypress.on('uncaught:exception', (err) => {
   if (
     err.message.includes('Request failed with status code 401') ||
     err.message.includes('Request failed with status code 403') ||
-    err.message.includes('undefined')||
+    err.message.includes('undefined') ||
     err.message.includes('postMessage') ||
-    err.message.includes('canceled')
+    err.message.includes('canceled') ||
+    err.message.includes('CancelledError') ||
+    err.message.includes('Network Error')
   ) {
     return false;
   }
