@@ -107,7 +107,7 @@ class Command extends AbstractObject
         /*
          * enable_shell is 0 we remove it
          */
-        $command_line = html_entity_decode($this->commands[$command_id]['command_line_base']);
+        $command_line = html_entity_decode($this->commands[$command_id]['command_line_base'] ?? '');
         $command_line = str_replace('#BR#', "\\n", $command_line);
         $command_line = str_replace("@MAILER@", $this->mail_bin, $command_line);
         $command_line = str_replace("\n", " \\\n", $command_line);
