@@ -1,7 +1,7 @@
 import { useCallback, useEffect } from 'react';
 
 import { useCookies } from 'react-cookie';
-import { useNavigate } from 'react-router-dom';
+import { useNavigate, useSearchParams } from 'react-router-dom';
 import { FormikHelpers, FormikValues } from 'formik';
 import { useAtom, useSetAtom, useAtomValue } from 'jotai';
 import { useTranslation } from 'react-i18next';
@@ -51,6 +51,8 @@ import usePostLogin from './usePostLogin';
 import useWallpaper from './useWallpaper';
 
 interface UseLoginState {
+  authenticationError: string | null;
+  hasForcedProvider: boolean;
   loginPageCustomisation: LoginPageCustomisation;
   platformInstallationStatus: PlatformInstallationStatus | null;
   providersConfiguration: Array<ProviderConfiguration> | null;
@@ -68,11 +70,11 @@ const getForcedProviders = filter<ProviderConfiguration>(
 );
 
 const getExternalProviders = reject<ProviderConfiguration>(
-  propEq('name', 'local')
+  propEq('local', 'name')
 );
 
 const getActiveProviders = filter<ProviderConfiguration>(
-  propEq('isActive', true)
+  propEq(true, 'isActive')
 );
 
 const defaultLoginPageCustomisation: LoginPageCustomisation = {
@@ -84,12 +86,14 @@ const defaultLoginPageCustomisation: LoginPageCustomisation = {
 };
 
 export const router = {
-  useNavigate
+  useNavigate,
+  useSearchParams
 };
 
 const useLogin = (): UseLoginState => {
   const { t, i18n } = useTranslation();
   const { sendLogin } = usePostLogin();
+  const [searchParams] = router.useSearchParams();
 
   const [cookies] = useCookies(['REDIRECT_URI']);
 
@@ -134,7 +138,7 @@ const useLogin = (): UseLoginState => {
 
   const checkPasswordExpiration = useCallback(
     ({ error, alias, setSubmitting }) => {
-      const isUserNotAllowed = propEq('statusCode', 401, error);
+      const isUserNotAllowed = propEq(401, 'statusCode', error);
 
       const { password_is_expired: passwordIsExpired } = prop(
         'additionalInformation',
@@ -162,8 +166,10 @@ const useLogin = (): UseLoginState => {
     { setSubmitting }
   ): void => {
     sendLogin({
-      login: values.alias,
-      password: values.password
+      payload: {
+        login: values.alias,
+        password: values.password
+      }
     })
       .then((response) => {
         if ((response as ResponseError).isError) {
@@ -203,6 +209,8 @@ const useLogin = (): UseLoginState => {
 
   const wallpaper = useWallpaper();
 
+  const authenticationError = searchParams.get('authenticationError');
+
   const loginPageCustomisation = isFetching
     ? defaultLoginPageCustomisation
     : {
@@ -229,14 +237,16 @@ const useLogin = (): UseLoginState => {
   }, [cookies]);
 
   useEffect(() => {
-    if (isEmpty(forcedProviders)) {
+    if (isEmpty(forcedProviders) || authenticationError) {
       return;
     }
 
     window.location.replace(forcedProviders[0].authenticationUri);
-  }, [forcedProviders]);
+  }, [forcedProviders, authenticationError]);
 
   return {
+    authenticationError,
+    hasForcedProvider: !!forcedProviders,
     loginPageCustomisation,
     platformInstallationStatus,
     providersConfiguration: activeProviders,
