@@ -1,5 +1,4 @@
 import axios from 'axios';
-import { Provider } from 'jotai';
 
 import { ListingVariant } from '@centreon/ui-context';
 import {
@@ -7,7 +6,7 @@ import {
   RenderResult,
   waitFor,
   screen
-} from '@centreon/ui/src/testRenderer';
+} from '@centreon/ui/test/testRenderer';
 
 import {
   platformInstallationStatusEndpoint,
@@ -26,8 +25,7 @@ import { navigationEndpoint } from '../Navigation/useNavigation';
 import { labelAuthenticationDenied } from '../FallbackPages/AuthenticationDenied/translatedLabels';
 
 import { labelCentreonIsLoading } from './translatedLabels';
-
-import Main from '.';
+import Provider from './Provider';
 
 const mockedAxios = axios as jest.Mocked<typeof axios>;
 
@@ -77,8 +75,12 @@ const retrievedTranslations = {
 const retrievedWeb = {
   modules: {},
   web: {
-    version: '21.10.1'
-  }
+    fix: '0',
+    major: '23',
+    minor: '04',
+    version: '23.04.1'
+  },
+  widgets: {}
 };
 
 const retrievedLoginConfiguration = {
@@ -121,12 +123,7 @@ jest.mock('../components/mainRouter', () => {
   };
 });
 
-const renderMain = (): RenderResult =>
-  render(
-    <Provider>
-      <Main />
-    </Provider>
-  );
+const renderMain = (): RenderResult => render(<Provider />);
 
 const mockDefaultGetRequests = (): void => {
   mockedAxios.get
@@ -216,15 +213,15 @@ const mockNotConnectedGetRequests = (): void => {
     .mockRejectedValueOnce({
       response: { status: 403 }
     })
-    .mockResolvedValueOnce({
-      data: retrievedWeb
-    })
     .mockResolvedValueOnce({
       data: {
         feature_flags: {},
         is_cloud_platform: false
       }
     })
+    .mockResolvedValueOnce({
+      data: retrievedWeb
+    })
     .mockResolvedValueOnce({
       data: retrievedTranslations
     })
@@ -308,8 +305,6 @@ describe('Main', () => {
 
     renderMain();
 
-    expect(screen.getByText(labelCentreonIsLoading)).toBeInTheDocument();
-
     await waitFor(() => {
       expect(mockedAxios.get).toHaveBeenCalledWith(
         platformInstallationStatusEndpoint,
