@@ -60,7 +60,8 @@ const useStyles = makeStyles()((theme) => ({
     paddingBottom: theme.spacing(1)
   },
   timeline: {
-    margin: 0
+    margin: 0,
+    padding: theme.spacing(0, 2, 0.5, 2)
   },
   timelineDot: {
     '> div, svg': {
