@@ -274,11 +274,8 @@ $pollerName = $pollerList[$selectedPoller];
 
 $path = "./include/Administration/brokerPerformance/";
 
-/*
- * Smarty template Init
- */
-$tpl = new Smarty();
-$tpl = initSmartyTpl($path, $tpl, "./");
+// Smarty template initialization
+$tpl = SmartyBC::createSmartyTemplate($path, "./");
 
 $renderer = new HTML_QuickForm_Renderer_ArraySmarty($tpl);
 $form->accept($renderer);
