@@ -59,8 +59,7 @@ if ($search) {
 $rq = "
     SELECT SQL_CALC_FOUND_ROWS acl_res_id, acl_res_name, acl_res_alias, all_hosts, all_hostgroups,
     all_servicegroups, acl_res_activate FROM acl_resources
-    WHERE locked = 0
-    $searchStr
+    WHERE locked = 0 AND cloud_specific = 0 $searchStr
     ORDER BY acl_res_name
     LIMIT :num, :limit
 ";
@@ -76,11 +75,8 @@ $rows = $pearDB->query("SELECT FOUND_ROWS()")->fetchColumn();
 
 include("./include/common/checkPagination.php");
 
-/*
- * Smarty template Init
- */
-$tpl = new Smarty();
-$tpl = initSmartyTpl(__DIR__, $tpl);
+// Smarty template initialization
+$tpl = SmartyBC::createSmartyTemplate(__DIR__);
 
 /*
  * start header menu
