@@ -34,6 +34,9 @@
  *
  */
 
+use Adaptation\Database\Connection\Collection\QueryParameters;
+use Adaptation\Database\Connection\Enum\QueryParameterTypeEnum;
+use Adaptation\Database\Connection\ValueObject\QueryParameter;
 use App\Kernel;
 use Centreon\Application\Controller\MonitoringResourceController;
 
@@ -45,7 +48,7 @@ require_once $centreon_path . 'www/class/centreonSession.class.php';
 require_once $centreon_path . 'www/class/centreonWidget.class.php';
 require_once $centreon_path . 'www/class/centreonDuration.class.php';
 require_once $centreon_path . 'www/class/centreonUtils.class.php';
-require_once $centreon_path . 'www/class/centreonACL.class.php';
+require_once $centreon_path . 'www/class/centreonAclLazy.class.php';
 require_once $centreon_path . 'www/class/centreonHost.class.php';
 require_once $centreon_path . 'www/class/centreonMedia.class.php';
 require_once $centreon_path . 'www/class/centreonCriticality.class.php';
@@ -55,19 +58,19 @@ if (!isset($_SESSION['centreon']) || !isset($_REQUEST['widgetId']) || !isset($_R
     exit;
 }
 
-$db = $dependencyInjector['configuration_db'];
-if (CentreonSession::checkSession(session_id(), $db) == 0) {
+$configurationDatabase = $dependencyInjector['configuration_db'];
+if (CentreonSession::checkSession(session_id(), $configurationDatabase) == 0) {
     exit;
 }
 
 /**
- * @var $dbb CentreonDB
+ * @var CentreonDB $realtimeDatabase
  */
-$dbb = $dependencyInjector['realtime_db'];
+$realtimeDatabase = $dependencyInjector['realtime_db'];
 
-/* Init Objects */
-$criticality = new CentreonCriticality($db);
-$media = new CentreonMedia($db);
+// Init Objects
+$criticality = new CentreonCriticality($configurationDatabase);
+$media = new CentreonMedia($configurationDatabase);
 
 // Smarty template initialization
 $path = $centreon_path . 'www/widgets/host-monitoring/src/';
@@ -89,7 +92,7 @@ $page = filter_input(INPUT_GET, 'page', FILTER_VALIDATE_INT, ['options' => ['def
 $mainQueryParameters = [];
 
 try {
-    $widgetObj = new CentreonWidget($centreon, $db);
+    $widgetObj = new CentreonWidget($centreon, $configurationDatabase);
     $preferences = $widgetObj->getWidgetPreferences($widgetId);
 } catch (Exception $e) {
     CentreonLog::create()->error(
@@ -102,47 +105,76 @@ try {
 }
 
 // Default colors
-$stateColors = getColors($db);
+$stateColors = getColors($configurationDatabase);
 // Get status labels
 $stateLabels = getLabels();
 
-$aStateType = ['1' => 'H', '0' => 'S'];
+$aStateType = [
+    '1' => 'H',
+    '0' => 'S',
+];
+
+$querySelect = <<<'SQL'
+        SELECT SQL_CALC_FOUND_ROWS
+            1 AS REALTIME,
+            h.host_id,
+            h.name AS host_name,
+            h.alias,
+            h.flapping,
+            state,
+            state_type,
+            address,
+            last_hard_state,
+            output,
+            scheduled_downtime_depth,
+            acknowledged,
+            notify,
+            active_checks,
+            passive_checks,
+            last_check,
+            last_state_change,
+            last_hard_state_change,
+            check_attempt,
+            max_check_attempts,
+            action_url,
+            notes_url,
+            cv.value AS criticality,
+            h.icon_image,
+            h.icon_image_alt,
+            cv2.value AS criticality_id,
+            cv.name IS NULL as isnull
+    SQL;
+
+$baseQuery = <<<'SQL'
+        FROM hosts h
+        LEFT JOIN `customvariables` cv
+            ON (cv.host_id = h.host_id AND cv.service_id = 0 AND cv.name = 'CRITICALITY_LEVEL')
+        LEFT JOIN `customvariables` cv2
+            ON (cv2.host_id = h.host_id AND cv2.service_id = 0 AND cv2.name = 'CRITICALITY_ID')
+    SQL;
+
+if (! $centreon->user->admin) {
+    $acls = new CentreonAclLazy($centreon->user->user_id);
+    $accessGroups = $acls->getAccessGroups()->getIds();
+
+    ['parameters' => $accessGroupParameters, 'placeholderList' => $accessGroupList] = createMultipleBindParameters(
+        $accessGroups,
+        'access_group',
+        QueryParameterTypeEnum::INTEGER
+    );
+
+    $baseQuery .= <<<SQL
+            INNER JOIN centreon_acl acl
+                ON h.host_id = acl.host_id
+                AND acl.service_id IS NULL
+                AND acl.group_id IN ({$accessGroupList})
+        SQL;
+
+    $mainQueryParameters = [...$accessGroupParameters, ...$mainQueryParameters];
+}
+
+$baseQuery .= " WHERE enabled = 1 AND h.name NOT LIKE '_Module_%'";
 
-$query = 'SELECT SQL_CALC_FOUND_ROWS
-    1 AS REALTIME,
-    h.host_id,
-    h.name AS host_name,
-    h.alias,
-    h.flapping,
-    state,
-    state_type,
-    address,
-    last_hard_state,
-    output,
-    scheduled_downtime_depth,
-    acknowledged,
-    notify,
-    active_checks,
-    passive_checks,
-    last_check,
-    last_state_change,
-    last_hard_state_change,
-    check_attempt,
-    max_check_attempts,
-    action_url,
-    notes_url,
-    cv.value AS criticality,
-    h.icon_image,
-    h.icon_image_alt,
-    cv2.value AS criticality_id,
-    cv.name IS NULL as isnull
-    FROM hosts h
-    LEFT JOIN `customvariables` cv
-        ON (cv.host_id = h.host_id AND cv.service_id = 0 AND cv.name = \'CRITICALITY_LEVEL\')
-    LEFT JOIN `customvariables` cv2
-        ON (cv2.host_id = h.host_id AND cv2.service_id = 0 AND cv2.name = \'CRITICALITY_ID\')
-    WHERE enabled = 1
-    AND h.name NOT LIKE \'_Module_%\' ';
 $stateTab = [];
 
 if (isset($preferences['host_name_search']) && $preferences['host_name_search'] != '') {
@@ -154,17 +186,17 @@ if (isset($preferences['host_name_search']) && $preferences['host_name_search']
     }
 
     if ($op && isset($search) && $search != '') {
-        $mainQueryParameters[] = ['parameter' => ':host_name_search', 'value' => $search, 'type' => PDO::PARAM_STR];
+        $mainQueryParameters[] = QueryParameter::string('host_name_search', $search);
         $hostNameCondition = 'h.name ' . CentreonUtils::operandToMysqlFormat($op) . ' :host_name_search ';
-        $query = CentreonUtils::conditionBuilder($query, $hostNameCondition);
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, $hostNameCondition);
     }
 }
 
 if (isset($preferences['notification_filter']) && $preferences['notification_filter']) {
-    if ($preferences['notification_filter'] == "enabled") {
-        $query = CentreonUtils::conditionBuilder($query, " notify = 1");
-    } elseif ($preferences['notification_filter'] == "disabled") {
-        $query = CentreonUtils::conditionBuilder($query, " notify = 0");
+    if ($preferences['notification_filter'] == 'enabled') {
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' notify = 1');
+    } elseif ($preferences['notification_filter'] == 'disabled') {
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' notify = 0');
     }
 }
 
@@ -177,80 +209,77 @@ if (isset($preferences['host_down']) && $preferences['host_down']) {
 if (isset($preferences['host_unreachable']) && $preferences['host_unreachable']) {
     $stateTab[] = 2;
 }
-if (count($stateTab)) {
-    $query = CentreonUtils::conditionBuilder($query, ' state IN (' . implode(',', $stateTab) . ')');
+if ($stateTab !== []) {
+    $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' state IN (' . implode(',', $stateTab) . ')');
 }
 if (isset($preferences['acknowledgement_filter']) && $preferences['acknowledgement_filter']) {
     if ($preferences['acknowledgement_filter'] == 'ack') {
-        $query = CentreonUtils::conditionBuilder($query, ' acknowledged = 1');
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' acknowledged = 1');
     } elseif ($preferences['acknowledgement_filter'] == 'nack') {
-        $query = CentreonUtils::conditionBuilder($query, ' acknowledged = 0');
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' acknowledged = 0');
     }
 }
 
 if (isset($preferences['downtime_filter']) && $preferences['downtime_filter']) {
     if ($preferences['downtime_filter'] == 'downtime') {
-        $query = CentreonUtils::conditionBuilder($query, ' scheduled_downtime_depth > 0 ');
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' scheduled_downtime_depth > 0 ');
     } elseif ($preferences['downtime_filter'] == 'ndowntime') {
-        $query = CentreonUtils::conditionBuilder($query, ' scheduled_downtime_depth = 0 ');
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' scheduled_downtime_depth = 0 ');
     }
 }
 
 if (isset($preferences['poller_filter']) && $preferences['poller_filter']) {
-    $query = CentreonUtils::conditionBuilder($query, ' instance_id = ' . $preferences['poller_filter'] . ' ');
+    $mainQueryParameters[] = QueryParameter::int('instance_id', (int) $preferences['poller_filter']);
+    $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' instance_id = :instance_id ');
 }
 
 if (isset($preferences['state_type_filter']) && $preferences['state_type_filter']) {
     if ($preferences['state_type_filter'] == 'hardonly') {
-        $query = CentreonUtils::conditionBuilder($query, ' state_type = 1 ');
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' state_type = 1 ');
     } elseif ($preferences['state_type_filter'] == 'softonly') {
-        $query = CentreonUtils::conditionBuilder($query, ' state_type = 0 ');
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, ' state_type = 0 ');
     }
 }
 
 if (isset($preferences['hostgroup']) && $preferences['hostgroup']) {
     $results = explode(',', $preferences['hostgroup']);
-    $queryHg = '';
-    foreach ($results as $result) {
-        if ($queryHg != '') {
-            $queryHg .= ', ';
-        }
-        $queryHg .= ":id_" . $result;
-        $mainQueryParameters[] = [
-            'parameter' => ':id_' . $result,
-            'value' => (int)$result,
-            'type' => PDO::PARAM_INT
-        ];
+
+    if ($results !== []) {
+        ['parameters' => $hostGroupIdsParameters, 'placeholderList' => $hostGroupList] = createMultipleBindParameters(
+            $results,
+            'hg_id',
+            QueryParameterTypeEnum::INTEGER,
+        );
+
+        $hostgroupHgIdCondition = <<<SQL
+            h.host_id IN (
+                  SELECT host_id
+                  FROM hosts_hostgroups
+                  WHERE hostgroup_id IN ({$hostGroupList}))
+            SQL;
+
+        $baseQuery = CentreonUtils::conditionBuilder($baseQuery, $hostgroupHgIdCondition);
+
+        $mainQueryParameters = [...$mainQueryParameters, ...$hostGroupIdsParameters];
     }
-    $hostgroupHgIdCondition = <<<SQL
-        h.host_id IN (
-              SELECT host_id
-              FROM hosts_hostgroups
-              WHERE hostgroup_id IN ({$queryHg}))
+}
+
+if (! empty($preferences['display_severities']) && ! empty($preferences['criticality_filter'])) {
+    $severities = explode(',', $preferences['criticality_filter']);
+
+    ['parameters' => $severityParameters, 'placeholderList' => $severityList] = createMultipleBindParameters(
+        $severities,
+        'severity_id',
+        QueryParameterTypeEnum::INTEGER,
+    );
+
+    $severityIdCondition = <<<SQL
+            cv2.value IN ({$severityList})
         SQL;
-    $query = CentreonUtils::conditionBuilder($query, $hostgroupHgIdCondition);
-}
-if (!empty($preferences['criticality_filter'])) {
-    $tab = explode(',', $preferences['criticality_filter']);
-    $labels = '';
-    foreach ($tab as $p) {
-        if ($labels != '') {
-            $labels .= ',';
-        }
-        $labels .= ":severity_id_" . $p;
-        $mainQueryParameters[] = [
-            'parameter' => ":severity_id_" . $p,
-            'value' => (int)$p,
-            'type' => PDO::PARAM_INT
-        ];
-    }
-    $severityIdCondition = 'cv2.value IN (' . $labels . ')';
-    $query = CentreonUtils::conditionBuilder($query, $severityIdCondition);
-}
-if (!$centreon->user->admin) {
-    $pearDB = $db;
-    $aclObj = new CentreonACL($centreon->user->user_id, $centreon->user->admin);
-    $query .= $aclObj->queryBuilder('AND', 'h.host_id', $aclObj->getHostsString('ID', $dbb));
+
+    $mainQueryParameters = [...$mainQueryParameters, ...$severityParameters];
+
+    $baseQuery = CentreonUtils::conditionBuilder($baseQuery, $severityIdCondition);
 }
 
 // prepare order_by
@@ -295,41 +324,19 @@ if ($orderByToAnalyse !== null) {
 }
 
 // concatenate order by + limit + offset  to the query
-$query .= "ORDER BY " . $orderBy . " LIMIT :limit OFFSET :offset";
-
-$num = filter_var($preferences['entries'], FILTER_VALIDATE_INT) ?: 10;
-$mainQueryParameters[] = [
-    'parameter' => "limit",
-    'value' => $num,
-    'type' => PDO::PARAM_INT
-];
-$mainQueryParameters[] = [
-    'parameter' => "offset",
-    'value' => ($page * $num),
-    'type' => PDO::PARAM_INT
-];
+$baseQuery .= ' ORDER BY ' . $orderBy;
 
 try {
-    $res = $dbb->prepare($query);
-    foreach ($mainQueryParameters as $parameter) {
-        $res->bindValue($parameter['parameter'], $parameter['value'], $parameter['type']);
-    }
-    $res->execute();
-} catch (PDOException $e) {
-    CentreonLog::create()->error(
-        CentreonLog::TYPE_SQL,
-        'Error while getting hosts for the host monitoring custom view',
-        ['pdo_info' => $e->errorInfo, 'query_parameters' => $mainQueryParameters],
-        $e
+    $recordIds = $realtimeDatabase->fetchAllAssociative('SELECT h.host_id' . $baseQuery, QueryParameters::create($mainQueryParameters));
+
+    $hostIds = array_map(
+        fn (array $record) => $record['host_id'],
+        $recordIds,
     );
-    throw $e;
-}
 
-unset($mainQueryParameters);
+    $nbRows = count($hostIds);
 
-
-try {
-    $nbRows = (int) $dbb->query('SELECT FOUND_ROWS() AS REALTIME')->fetchColumn();
+    CentreonSession::writeSessionClose(sprintf('w_hm_%d', $widgetId), $hostIds);
 } catch (PDOException $e) {
     CentreonLog::create()->error(
         CentreonLog::TYPE_SQL,
@@ -340,12 +347,32 @@ try {
     throw $e;
 }
 
+$query = $querySelect . $baseQuery . ' LIMIT :limit OFFSET :offset';
+
+$num = filter_var($preferences['entries'], FILTER_VALIDATE_INT) ?: 10;
+
+$mainQueryParameters[] = QueryParameter::int('limit', $num);
+$mainQueryParameters[] = QueryParameter::int('offset', ($page * $num));
+
+try {
+    $records = $realtimeDatabase->fetchAllAssociative($query, QueryParameters::create($mainQueryParameters));
+} catch (PDOException $e) {
+    CentreonLog::create()->error(
+        CentreonLog::TYPE_SQL,
+        'Error while getting hosts for the host monitoring custom view',
+        ['pdo_info' => $e->errorInfo, 'query_parameters' => $mainQueryParameters],
+        $e
+    );
+
+    throw $e;
+}
+
 $data = [];
 $outputLength = $preferences['output_length'] ?: 50;
 $commentLength = $preferences['comment_length'] ?: 50;
 
 try {
-    $hostObj = new CentreonHost($db);
+    $hostObj = new CentreonHost($configurationDatabase);
 } catch (PDOException $e) {
     CentreonLog::create()->error(
         CentreonLog::TYPE_SQL,
@@ -360,9 +387,8 @@ $gmt = new CentreonGMT();
 $gmt->getMyGMTFromSession(session_id());
 $allowedActionProtocols = ['http[s]?', '//', 'ssh', 'rdp', 'ftp', 'sftp'];
 $allowedProtocolsRegex = '#(^' . implode(')|(^', $allowedActionProtocols) . ')#';
-// String starting with one of these protocols
 
-while ($row = $res->fetch()) {
+foreach ($records as $row) {
     foreach ($row as $key => $value) {
         $data[$row['host_id']][$key] = $value;
     }
@@ -372,7 +398,7 @@ while ($row = $res->fetch()) {
     $valueLastCheckTimestamp = time() - $valueLastCheck;
     if (
         $valueLastCheckTimestamp > 0
-        && $valueLastCheckTimestamp < 3600
+            && $valueLastCheckTimestamp < 3600
     ) {
         $valueLastCheck = CentreonDuration::toString($valueLastCheckTimestamp) . ' ago';
     }
@@ -414,8 +440,8 @@ while ($row = $res->fetch()) {
 
     $resourceController = $kernel->getContainer()->get(MonitoringResourceController::class);
     $data[$row['host_id']]['details_uri'] = $useDeprecatedPages
-        ? '../../main.php?p=20202&o=hd&host_name=' . $row['host_name']
-        : $resourceController->buildHostDetailsUri($row['host_id']);
+    ? '../../main.php?p=20202&o=hd&host_name=' . $row['host_name']
+    : $resourceController->buildHostDetailsUri($row['host_id']);
 
     // action_url
     $valueActionUrl = $row['action_url'];
@@ -459,19 +485,14 @@ while ($row = $res->fetch()) {
 
     if (isset($preferences['display_last_comment']) && $preferences['display_last_comment']) {
         try {
-            $query = <<<SQL
+            $baseQuery = <<<'SQL'
                 SELECT data FROM comments where host_id = :hostId
                 AND service_id = 0 ORDER BY entry_time DESC LIMIT 1
-            SQL;
-            $res2 = $dbb->prepare($query);
+                SQL;
+            $res2 = $realtimeDatabase->prepare($baseQuery);
             $res2->bindValue(':hostId', $row['host_id'], PDO::PARAM_INT);
             $res2->execute();
-            if ($row2 = $res2->fetch()) {
-                $data[$row['host_id']]['comment'] = substr($row2['data'], 0, $commentLength);
-            } else {
-                $data[$row['host_id']]['comment'] = '-';
-            }
-            $res2->closeCursor();
+            $data[$row['host_id']]['comment'] = ($row2 = $res2->fetch()) ? substr($row2['data'], 0, $commentLength) : '-';
         } catch (PDOException $e) {
             CentreonLog::create()->error(
                 CentreonLog::TYPE_SQL,
@@ -498,8 +519,6 @@ while ($row = $res->fetch()) {
     $data[$row['host_id']]['class_tr'] = $class;
 }
 
-$res->closeCursor();
-
 $aColorHost = [
     0 => 'host_up',
     1 => 'host_down',
